### ⚡hwrag: A Python Toolkit for RAG to build a efficient and productive applicaton

<p align="center">
<img src="asset/rag.jpg">
</p>

## Installation

To get started with hwrag, simply install (requires Python 3.9+):

```bash
pip install hwrag
```

## License

hwrag is licensed under the [MIT License](./LICENSE).

## Citation

If you used hwrag in your research, please cite as follows:

```latex
@misc{hwrag,
  title={hwrag: A Python Toolkit for RAG to build a efficient and productive applicaton.},
  author={Xinping Huang and Ye Jin},
  year={2024},
  howpublished={\url{https://github.com/huangxinping/hwrag}},
}
```
